@@ -8,4 +8,4 @@ CONBINE_STRING = getattr(settings, 'POSITION_COMBINE_STRING', '__')
 
 # List of templates per model
 # EX: {"stories.story": "customtemplates/stories/position_render.html"}
-TEMPLATES = getattr(settings, "POSITION_TEMPLATES", {})
\ No newline at end of file
+# TEMPLATES = getattr(settings, "POSITION_TEMPLATES", {})
\ No newline at end of file
